@@ -843,7 +843,9 @@ SPI_fname(TupleDesc tupdesc, int fnumber)
 char *
 SPI_getvalue(HeapTuple tuple, TupleDesc tupdesc, int fnumber)
 {
-	Datum		val;
+	char	   *result;
+	Datum		origval,
+				val;
 	bool		isnull;
 	Oid			typoid,
 				foutoid;
@@ -858,7 +860,7 @@ SPI_getvalue(HeapTuple tuple, TupleDesc tupdesc, int fnumber)
 		return NULL;
 	}
 
-	val = heap_getattr(tuple, fnumber, tupdesc, &isnull);
+	origval = heap_getattr(tuple, fnumber, tupdesc, &isnull);
 	if (isnull)
 		return NULL;
 
@@ -869,7 +871,22 @@ SPI_getvalue(HeapTuple tuple, TupleDesc tupdesc, int fnumber)
 
 	getTypeOutputInfo(typoid, &foutoid, &typisvarlena);
 
-	return OidOutputFunctionCall(foutoid, val);
+	/*
+	 * If we have a toasted datum, forcibly detoast it here to avoid memory
+	 * leakage inside the type's output routine.
+	 */
+	if (typisvarlena)
+		val = PointerGetDatum(PG_DETOAST_DATUM(origval));
+	else
+		val = origval;
+
+	result = OidOutputFunctionCall(foutoid, val);
+
+	/* Clean up detoasted copy, if any */
+	if (val != origval)
+		pfree(DatumGetPointer(val));
+
+	return result;
 }
 
 Datum
